@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods and functions
 
-our $VERSION = '0.0602';
+our $VERSION = '0.0603';
 
 use Moo;
 use strictures 2;
@@ -127,7 +127,7 @@ Test::NaiveStubs - Generate test stubs for methods and functions
 
 =head1 VERSION
 
-version 0.0602
+version 0.0603
 
 =head1 SYNOPSIS
 
@@ -212,6 +212,9 @@ the subroutine is produced.
 
 =head1 SEE ALSO
 
+The F<eg/stub> example program and the F<t/01-methods.t> test in this
+distribution
+
 L<Moo>
 
 L<Package::Stash>
